@@ -274,23 +274,29 @@ class Controls:
         slider = self.controls[param]
         ipywidgets_slider = False
         if "Box" in str(slider.__class__):
-            ipywidgets_slider = True
             for obj in slider.children:
                 if "Slider" in str(obj.__class__):
                     slider = obj
-            N = int((slider.max - slider.min) / slider.step)
-            min_ = slider.min
-            max_ = slider.max
-            step = slider.step
-        elif isinstance(slider, mSlider):
+
+        if isinstance(slider, mSlider):
             min_ = slider.valmin
             max_ = slider.valmax
             if slider.valstep is None:
-                N = N_frames if N_frames else 200
-                step = (max_ - min_) / N
+                n_steps = N_frames if N_frames else 200
+                step = (max_ - min_) / n_steps
             else:
-                N = int((max_ - min_) / slider.valstep)
                 step = slider.valstep
+        elif "Slider" in str(slider.__class__):
+            ipywidgets_slider = True
+            min_ = slider.min
+            max_ = slider.max
+            step = slider.step
+        else:
+            raise NotImplementedError(
+                "Cannot save animation for slider of type %s".format(slider.__class__.__name__)
+            )
+
+        N = int((max_ - min_) / step)
 
         def f(i):
             val = min_ + step * i
